@@ -18,6 +18,8 @@ from benchmark_runner.benchmark_operator.benchmark_operator_exceptions import OC
 from benchmark_runner.main.environment_variables import environment_variables
 from benchmark_runner.common.clouds.IBM.ibm_operations import IBMOperations
 from benchmark_runner.common.clouds.shared.s3.s3_operations import S3Operations
+from benchmark_runner.common.prometheus.prometheus_snapshot import PrometheusSnapshot
+from benchmark_runner.common.prometheus.prometheus_snapshot_exceptions import PrometheusSnapshotError
 
 
 class BenchmarkOperatorWorkloads:
@@ -32,14 +34,18 @@ class BenchmarkOperatorWorkloads:
         self.__run_type = self.__environment_variables_dict.get('run_type', '')
         self.__system_metrics = self.__environment_variables_dict.get('system_metrics', '')
         self.__elasticsearch = self.__environment_variables_dict.get('elasticsearch', '')
-        self.__run_artifacts = self.__environment_variables_dict.get('run_artifacts_path', '')
+        self.__run_artifacts = self.__environment_variables_dict.get('run_artifacts', '')
+        self.__run_artifacts_path = self.__environment_variables_dict.get('run_artifacts_path', '')
         self.__date_key = self.__environment_variables_dict.get('date_key', '')
         self.__key = self.__environment_variables_dict.get('key', '')
+        self.__endpoint_url = self.__environment_variables_dict.get('endpoint_url', '')
+        self.__save_artifacts_local = self.__environment_variables_dict.get('save_artifacts_local', '')
+        self.__enable_prometheus_snapshot = self.__environment_variables_dict.get('enable_prometheus_snapshot', '')
         self.__ssh = SSH()
         self.__kubeadmin_password = kubeadmin_password
         self.__oc = OC(kubeadmin_password=self.__kubeadmin_password)
         self.__dir_path = f'{os.path.dirname(os.path.realpath(__file__))}'
-        self.__current_run_path = f'{self.__dir_path}/workload_flavors/current_run'
+        self.__current_run_path = os.path.join(f'{self.__dir_path}/workload_flavors/current_run')
         self.__es_host = es_host
         self.__es_port = es_port
         if es_host and es_port:
@@ -372,9 +378,9 @@ class BenchmarkOperatorWorkloads:
         This method tar.gz log path and return the tar.gz path
         :return:
         """
-        tar_run_artifacts_path = f"{self.__run_artifacts}.tar.gz"
+        tar_run_artifacts_path = f"{self.__run_artifacts_path}.tar.gz"
         with tarfile.open(tar_run_artifacts_path, mode='w:gz') as archive:
-            archive.add(self.__run_artifacts, arcname=f'{workload}-{self.__time_stamp_format}', recursive=True)
+            archive.add(self.__run_artifacts_path, arcname=f'{workload}-{self.__time_stamp_format}', recursive=True)
         return tar_run_artifacts_path
 
     @logger_time_stamp
@@ -384,21 +390,23 @@ class BenchmarkOperatorWorkloads:
         :param workload:
         :return:
         """
-        s3operations = S3Operations()
-        # change workload to key convention
         workload = workload.replace('_', '-')
         tar_run_artifacts_path = self.__make_run_artifacts_tarfile(workload)
         run_artifacts_hierarchy = self.__get_run_artifacts_hierarchy()
-        upload_file = f"{workload}-{self.__time_stamp_format}.tar.gz"
-        s3operations.upload_file(file_name_path=tar_run_artifacts_path,
-                                 bucket=self.__environment_variables_dict.get('bucket', ''),
-                                 key=run_artifacts_hierarchy,
-                                 upload_file=upload_file)
+        # Upload when endpoint_url is not None
+        if self.__endpoint_url:
+            s3operations = S3Operations()
+            # change workload to key convention
+            upload_file = f"{workload}-{self.__time_stamp_format}.tar.gz"
+            s3operations.upload_file(file_name_path=tar_run_artifacts_path,
+                                     bucket=self.__environment_variables_dict.get('bucket', ''),
+                                     key=run_artifacts_hierarchy,
+                                     upload_file=upload_file)
         # remove local run artifacts workload folder
         # verify that its not empty path
-        if len(self.__run_artifacts) > 3 and self.__run_artifacts != '/' and self.__run_artifacts and tar_run_artifacts_path and os.path.isfile(tar_run_artifacts_path):
+        if len(self.__run_artifacts_path) > 3 and self.__run_artifacts_path != '/' and self.__run_artifacts_path and tar_run_artifacts_path and os.path.isfile(tar_run_artifacts_path) and not self.__save_artifacts_local:
             # remove run_artifacts_path
-            shutil.rmtree(path=self.__run_artifacts)
+            shutil.rmtree(path=self.__run_artifacts_path)
             # remove tar.gz file
             os.remove(path=tar_run_artifacts_path)
 
@@ -814,12 +822,32 @@ class BenchmarkOperatorWorkloads:
         # make deploy benchmark controller manager
         self.make_deploy_benchmark_controller_manager(runner_path=environment_variables.environment_variables_dict['runner_path'])
 
+        # Start collection of Prometheus snapshot
+        if self.__enable_prometheus_snapshot:
+            try:
+                if not os.path.isdir(self.__run_artifacts_path):
+                    os.mkdir(self.__run_artifacts_path)
+                snapshot = PrometheusSnapshot(oc=self.__oc, artifacts_path=self.__run_artifacts_path, verbose=True)
+                snapshot.prepare_for_snapshot()
+            except PrometheusSnapshotError as err:
+                raise PrometheusSnapshotError(err)
+            except Exception as err:
+                raise err
+
         # run workload
         self.run_workload_func(workload_full_name=workload)
 
+        # Retrieve the Prometheus snapshot
+        if self.__enable_prometheus_snapshot:
+            try:
+                snapshot.retrieve_snapshot()
+            except PrometheusSnapshotError as err:
+                raise PrometheusSnapshotError(err)
+            except Exception as err:
+                raise err
+
         # upload logs to s3
         self.upload_run_artifacts_to_s3(workload=workload)
 
         # make undeploy benchmark controller manager
         self.make_undeploy_benchmark_controller_manager(runner_path=environment_variables.environment_variables_dict['runner_path'])
-
