@@ -7,7 +7,7 @@ from benchmark_runner.common.logger.logger_time_stamp import logger_time_stamp,
 from benchmark_runner.common.oc.oc_exceptions import PodNotCreateTimeout, PodNotInitializedTimeout, PodNotReadyTimeout, \
     PodNotCompletedTimeout, PodTerminateTimeout, PodNameNotExist, LoginFailed, VMNotCreateTimeout, VMTerminateTimeout, \
     YAMLNotExist, VMNameNotExist, VMNotInitializedTimeout, VMNotReadyTimeout, VMNotCompletedTimeout, \
-    OCPResourceNotCreateTimeout, KataInstallationFailed
+    OCPResourceNotCreateTimeout, KataInstallationFailed, ExecFailed, PodFailed
 from benchmark_runner.common.ssh.ssh import SSH
 from benchmark_runner.main.environment_variables import environment_variables
 
@@ -100,8 +100,8 @@ class OC(SSH):
         This method check if cnv operator is installed
         :return:
         """
-        verify_cmd = 'oc -n openshift-cnv wait deployment/virt-operator --for=condition=Available'
-        if 'met' in self.run(verify_cmd):
+        verify_cmd = "oc get csv -n openshift-cnv -ojsonpath='{.items[0].status.phase}'"
+        if 'Succeeded' in self.run(verify_cmd):
             return True
         return False
 
@@ -110,8 +110,8 @@ class OC(SSH):
         This method check if ocs operator is installed
         :return:
         """
-        verify_cmd = 'oc -n openshift-storage wait deployment/ocs-operator --for=condition=Available'
-        if 'met' in self.run(verify_cmd):
+        verify_cmd = "oc get csv -n openshift-storage -ojsonpath='{.items[0].status.phase}'"
+        if 'Succeeded' in self.run(verify_cmd):
             return True
         return False
 
@@ -120,8 +120,8 @@ class OC(SSH):
         This method check if kata operator is installed
         :return:
         """
-        verify_cmd = 'oc -n openshift-sandboxed-containers-operator wait deployment/controller-manager --for=condition=Available'
-        if 'met' in self.run(verify_cmd):
+        verify_cmd = "oc get csv -n openshift-sandboxed-containers-operator -ojsonpath='{.items[0].status.phase}'"
+        if 'Succeeded' in self.run(verify_cmd):
             return True
         return False
 
@@ -317,7 +317,7 @@ class OC(SSH):
         """
         output_filename = f"{self.__run_artifacts}/{vm_name}"
         self.run(
-            cmd=f"virtctl console -n {environment_variables.environment_variables_dict['namespace']} {vm_name} | tee -a {output_filename}",
+            cmd=f"virtctl console -n {environment_variables.environment_variables_dict['namespace']} {vm_name} > {output_filename}",
             background=True)
 
     @logger_time_stamp
@@ -591,6 +591,70 @@ class OC(SSH):
             current_wait_time += OC.SLEEP_TIME
         raise VMNotCompletedTimeout(workload=workload)
 
+    @typechecked
+    def exec(self, command: str, pod_name: str, namespace: str = '', container: str = ''):
+        """
+        oc exec a command and return the answer
+        :param command:
+        :param pod_name:
+        :param namespace:
+        :param container:
+        :return:
+        """
+        try:
+            if namespace != '':
+                namespace = f'-n {namespace}'
+            if container != '':
+                container = f'-c {container}'
+            return self.run(f'oc exec {namespace} {pod_name} {container} -- {command}')
+        except Exception as err:
+            raise ExecFailed(command, pod_name, err)
+
+    @typechecked
+    def terminate_pod_sync(self, pod_name: str,
+                           namespace: str = environment_variables.environment_variables_dict['namespace'],
+                           timeout: int = int(environment_variables.environment_variables_dict['timeout'])):
+        """
+        Delete a pod based on name and namespace only
+        :param pod_name:
+        :param namespace:
+        :param timeout:
+        :return:
+        """
+        if self._is_pod_exist(pod_name, namespace):
+            try:
+                if namespace != '':
+                    namespace = f'-n {namespace}'
+                self.run(f'oc delete pod {namespace} {pod_name} timeout={timeout}')
+            except Exception as err:
+                raise PodTerminateTimeout(pod_name)
+
+    @typechecked
+    @logger_time_stamp
+    def wait_for_pod_ready(self, pod_name: str,
+                           namespace: str = environment_variables.environment_variables_dict['namespace'],
+                           timeout: int = int(environment_variables.environment_variables_dict['timeout'])):
+        """
+        Wait for a pod to be ready and running
+        :param pod_name:
+        :param namespace:
+        :param timeout:
+        :return: True if getting pod name or raise PodNameError
+        """
+        self.wait_for_pod_create(pod_name=pod_name, namespace=namespace, timeout=timeout)
+        current_wait_time = 0
+        if namespace != '':
+            namespace=f'-n {namespace}'
+        while current_wait_time <= timeout:
+            answer = self.run(f'oc get pod {namespace} {pod_name} --no-headers -ocustom-columns=Status:status.phase 2>/dev/null')
+            if answer == 'Running':
+                return
+            elif answer == 'Error':
+                raise PodFailed(pod_name)
+            time.sleep(OC.SLEEP_TIME)
+            current_wait_time += OC.SLEEP_TIME
+        raise PodNotReadyTimeout(pod_name)
+
     def __get_num_active_nodes(self):
         """
         This method return the number of active nodes
@@ -667,7 +731,7 @@ class OC(SSH):
                 time.sleep(10)
             # Wait that till succeeded
             self.wait_for_ocp_resource_create(resource='cnv',
-                                              verify_cmd="oc get csv -n openshift-cnv $(oc get csv -n openshift-cnv --no-headers | awk '{ print $1; }') -ojsonpath='{.status.phase}'",
+                                              verify_cmd="oc get csv -n openshift-cnv -ojsonpath='{.items[0].status.phase}'",
                                               status='Succeeded')
         return True
 
@@ -733,7 +797,7 @@ class OC(SSH):
                     self.wait_for_ocp_resource_create(resource='ocs',
                                                       verify_cmd=r"""oc get pod -n openshift-storage | grep osd | grep -v prepare""")
                     self.wait_for_ocp_resource_create(resource='ocs',
-                                                      verify_cmd="oc get csv -n openshift-storage $(oc get csv -n openshift-storage --no-headers | awk '{ print $1; }') -ojsonpath='{.status.phase}'",
+                                                      verify_cmd="oc get csv -n openshift-storage -ojsonpath='{.items[0].status.phase}'",
                                                       status='Succeeded')
                     self.wait_for_ocp_resource_create(resource='ocs',
                                                       verify_cmd='oc get pod -n openshift-storage | grep osd | grep -v prepare | wc -l',
